@@ -1,5 +1,5 @@
 /**
- * Copyright (C) 2022-2024 the Eask authors.
+ * Copyright (C) 2022-2025 the Eask authors.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -50,7 +50,7 @@ exports.handler = async (argv) => {
   }
 
   process.env.PATH = fs.readFileSync(epf, 'utf8');
-  process.env.EMACSLOADPATH = fs.readFileSync(lpf, 'utf8');;
+  process.env.EMACSLOADPATH = fs.readFileSync(lpf, 'utf8');
 
   let proc = child_process.spawn(UTIL.cli_args(cmd), { stdio: 'inherit', shell: true });
 
