@@ -5,8 +5,11 @@
 ;;
 ;;; Requirement
 
-(when (version< emacs-version "26.1")
-  (error "Eask requires Emacs 26.1 and above!"))
+(defconst eask-required-emacs-version "26.1"
+  "The minimum Emacs version required to run Eask.")
+
+(when (version< emacs-version eask-required-emacs-version)
+  (error "Eask requires Emacs %s and above!" eask-required-emacs-version))
 
 ;;
 ;;; Includes
@@ -408,11 +411,20 @@ and INHERIT-INPUT-METHOD see function `read-string' for more information."
 
 For arguments OLD, NEW and S; see the function `eask-s-replace'
 for more information."
-  (if-let* ((data   (eask-ansi-codes s))
-            (start  (nth 1 data))
-            (end    (nth 0 data))
-            (splits (split-string s (regexp-quote old))))
-      (mapconcat #'identity splits (concat start new end))
+  (if-let* ((splits (split-string s (regexp-quote old))))
+      (let* ((reset "\e[0m")
+             (result (nth 0 splits))
+             (index  1)
+             (last))
+        (while (< index (length splits))
+          (let* ((data (eask-ansi-codes result)))
+            (setq last (car (last data))
+                  result (concat result
+                                 (if (null last) "" reset) new last
+                                 (nth index splits))))
+          (cl-incf index))
+        ;; Just ensure the last character is reset.
+        (concat result (if (null last) "" reset)))
     (eask-s-replace old new s)))
 
 ;;
@@ -438,7 +450,7 @@ for more information."
            (if (< elapsed eask-minimum-reported-time)
                (ignore-errors (eask-msg ,msg-end))
              (ignore-errors (eask-write ,msg-end))
-             (eask-msg (format " (%.3fs)" elapsed)))))
+             (eask-msg " (%.3fs)" elapsed))))
      (ignore-errors (eask-write ,msg-start)) ,body
      (ignore-errors (eask-msg ,msg-end))))
 
@@ -790,9 +802,10 @@ The optional argument URL-OR-PACKAGE is used in the function `try'."
   (eask--pkg-process pkg
     (cond
      ((and installed-p (not should-reinstall-p))
-      (eask-msg "  - %sSkipping %s (%s)... already installed ✗"
-                eask--action-prefix
-                name version))
+      (eask-with-progress
+        (format "  - %sSkipping %s (%s)... " eask--action-prefix name version)
+        (progn )  ; no operation needed
+        "already installed ✗"))
      (t
       (eask-with-progress
         (format "  - %s%snstalling %s (%s)... " eask--action-prefix
@@ -811,9 +824,10 @@ The optional argument URL-OR-PACKAGE is used in the function `try'."
   (eask--pkg-process pkg
     (cond
      ((and installed-p (not should-reinstall-p))
-      (eask-msg "  - %sSkipping %s (%s)... already installed ✗"
-                eask--action-prefix
-                name version))
+      (eask-with-progress
+        (format "  - %sSkipping %s (%s)... " eask--action-prefix name version)
+        (progn )  ; no operation needed
+        "already installed ✗"))
      (t
       (eask-with-progress
         (format "  - %s%snstalling %s (%s)... " eask--action-prefix
@@ -839,9 +853,10 @@ The optional argument URL-OR-PACKAGE is used in the function `try'."
   (eask--pkg-process pkg
     (cond
      ((and installed-p (not should-reinstall-p))
-      (eask-msg "  - %sSkipping %s (%s)... already installed ✗"
-                eask--action-prefix
-                name version))
+      (eask-with-progress
+        (format "  - %sSkipping %s (%s)... " eask--action-prefix name version)
+        (progn )  ; no operation needed
+        "already installed ✗"))
      ((progn
         (eask-pkg-init)
         (unless (eask-package-installable-p pkg)
@@ -872,7 +887,10 @@ The optional argument URL-OR-PACKAGE is used in the function `try'."
   (eask--pkg-process pkg
     (cond
      ((not installed-p)
-      (eask-msg "  - %sSkipping %s (%s)... not installed ✗" eask--action-prefix name version))
+      (eask-with-progress
+        (format "  - %sSkipping %s (%s)... " eask--action-prefix name version)
+        (progn )  ; no operation needed
+        "not installed ✗"))
      (t
       (eask--pkg-process pkg  ; Second call to force refresh the data.
         (eask-with-progress
@@ -888,7 +906,10 @@ The optional argument URL-OR-PACKAGE is used in the function `try'."
     (cond
      ;; You cannot reinstall the package that are not installed.
      ((not installed-p)
-      (eask-msg "  - %sSkipping %s (%s)... not installed ✗" eask--action-prefix name version))
+      (eask-with-progress
+        (format "  - %sSkipping %s (%s)... " eask--action-prefix name version)
+        (progn )  ; no operation needed
+        "not installed ✗"))
      (t
       (eask-pkg-init)
       (eask--pkg-process pkg  ; Second call to force refresh the data.
