@@ -27,7 +27,9 @@
 ;;
 ;;; Flags
 
-(advice-add #'eask-allow-error-p :override #'always)
+(eask-command-check "29.1")
+
+(advice-add #'eask-allow-error-p :override #'eask-always)
 
 ;;
 ;;; Core
