@@ -17,7 +17,7 @@
 ;;
 ;;; Flags
 
-(advice-add #'eask-allow-error-p :override #'always)
+(advice-add #'eask-allow-error-p :override #'eask-always)
 
 ;;
 ;;; Core
@@ -31,7 +31,8 @@
 (eask-start
   ;; Preparation
   (eask-archive-install-packages '("gnu" "melpa")
-                                 '(package-lint pkg-info))
+                                 'package-lint
+                                 'pkg-info)
 
   ;; Start Testing
   (let* ((dirs (or (eask-args) `(,default-directory))))
